@@ -10,6 +10,9 @@
  */
 
 import org.gnome.gtk.Button;
+import org.gnome.gtk.FileChooser;
+import org.gnome.gtk.FileChooserAction;
+import org.gnome.gtk.FileChooserButton;
 import org.gnome.gtk.Gtk;
 import org.gnome.gtk.Label;
 import org.gnome.gtk.Object;
@@ -26,14 +29,21 @@ import org.gnome.gtk.Window;
  */
 public final class Experiment
 {
-
-    public static void main(String[] args) {
+    /*
+     * It is not, strictly speaking, necessary to put the UI building code
+     * into a constructor; there's nothing wrong in a tiny program with doing
+     * it all in static code in main().
+     * 
+     * What we gain, however, is that the references to all the objects
+     * created become unreachable as soon as it runs, and that allowed us to
+     * evaluate that the memory management is working correctly.
+     */
+    private Experiment() {
         final Window w;
         final VBox x;
         final Label l;
         final Button b;
-
-        Gtk.init(args);
+        final FileChooserButton fcb;
 
         w = new Window();
 
@@ -44,8 +54,12 @@ public final class Experiment
 
         b = new Button("Change Me?");
         b.setLabel("Press Me!");
+        b.setRelief(ReliefStyle.NORMAL);
         x.packStart(b);
 
+        fcb = new FileChooserButton("Good to get, a file is", FileChooserAction.OPEN);
+        x.packStart(fcb, false, false, 0);
+
         w.add(x);
 
         w.setTitle("Exp");
@@ -65,19 +79,26 @@ public final class Experiment
             }
         });
 
-        // attempt to set a non-zero enum, and make sure we get it back, by
-        // identity; Button's getRelief() is temporarily implemented with
-        // getPropertyEnum(). TODO move this to a unit test.
-        ReliefStyle rs = ReliefStyle.NONE;
-        b.setRelief(rs);
-        assert (b.getRelief() == rs);
+        fcb.connect(new FileChooser.SELECTION_CHANGED() {
+            public void onSelectionChanged(FileChooser source) {
+                System.out.println("File selected:   " + source.getURI());
+                System.gc();
+            }
+        });
+    }
 
-        // I actually prefer normal relief on buttons today :)
-        b.setRelief(ReliefStyle.NORMAL);
+    public static void main(String[] args) {
+        Gtk.init(args);
+
+        new Experiment();
 
         Gtk.main();
 
-        // verify we make it out of the main loop without crashing
+        // Observe release() being done on the various Proxies created. As
+        // ever, though, calling gc() is not imperative.
+        System.gc();
+
+        // And, hopefully, we make it out of the main loop without crashing
         System.out.println("Bye now.");
     }
 }
